validate_permutation

Function validate_permutation 

pub fn validate_permutation(perm: &[usize], n: usize) -> Result<(), SparseError>
Validate that perm is a valid permutation of 0..n.

Returns Ok(()) if perm has exactly n elements and is a bijection on 0..n.

Errors

  • perm.len() != n
  • Any element is out of bounds (>= n)
  • Any element appears more than once